View source: R/load_districts.R
| load_districts | R Documentation |
Load district boundaries for a specific year
load_districts(year = 2020)
year |
The year for which to load district boundaries (2010, 2015, or 2020) |
An sf object containing district boundaries for the specified year
This function requires the tidycensuskr.sf package to be installed.
No explicit dependency is defind; but users should install the package following
the instructions at vignette('v01_intro') or more succinctly:
install.packages('tidycensuskr.sf', repos = 'https://sigmafelix.r-universe.dev')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.