View source: R/set_kosis_key.R
| set_kosis_key | R Documentation |
This function reads a KOSIS API key from a specified file and sets it for use in KOSIS API calls.
set_kosis_key(file)
file |
A character string specifying the path to the file containing the KOSIS API key. |
The file should contain the API key as a single line of text. If the file does not exist, an error will be raised.
No return value. A message will be printed to confirm that the key has been set.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.