Learn R Programming

tidycensuskr (version 0.2.5)

adm2_sf_2020: South Korea Census Boundary in 2020

Description

District level boundary data in South Korea in 2020. adm2_code column can be used to join with an anycensus() output.

Usage

adm2_sf_2020

Arguments

Format

A sf object with 250 rows and 3 variables:

Details

  • year Year of the census data, e.g., 2010, 2015, or 2020

  • adm2_code Code of the district/municipal-level (Sigungu) administrative unit

  • geometry Geometry list-column