Learn R Programming

tidycensuskr (version 0.2.5)

censuskor: South Korea Census Data

Description

District level data including tax, population, business entities, housing, economy, medicine and mortality in South Korea in 2010, 2015, and/or 2020. The availble years and variables depend on the type of data.

Usage

censuskor

Arguments

Format

A data.frame with 67232 rows and 10 variables:

Details

  • year Year of the census data, e.g., 2010, 2015, or 2020

  • adm1 Name of the province-level (Sido) administrative unit

  • adm1_code Code of the province-level (Sido) administrative unit

  • adm2 Name of the district/municipal-level (Sigungu) administrative unit

  • adm2_code Code of the district/municipal-level (Sigungu) administrative unit

  • type Type of variable, e.g., "population", "tax", "mortality", "housing", "medicine", "migration", "environment", "welfare", or "economy"

  • class1 First-level classification of the variable depending on the type

  • class2 Second-level classification of the variable depending on the type

  • unit Unit of measurement for the variable

  • value Value of the variable