A geofacet grid for South Korea administrative districts (Si-Gun-Gu) based on the Statistical Geographic Information Service (SGIS) standard in 2020. Non-autonomous districts in cities are retained as separate entities. This grid can be used with the geofacet package to create faceted visualizations based on geographic layout.
kr_grid_adm2_sgis_2020A data.frame with 250 rows and 6 variables
name Name of the district/municipal-level (Sigungu) administrative unit
code SGIS code of the district/municipal-level (Sigungu) administrative unit
row Row position in the geofacet grid
col Column position in the geofacet grid